Class: Checkbook::CreateBankResponse
- Inherits:
-
Object
- Object
- Checkbook::CreateBankResponse
- Defined in:
- lib/checkbook/models/create_bank_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account ⇒ Object
Last 4 of account number.
-
#balance ⇒ Object
Indicates the current amount left in the account’s balance (only for prefunded accounts).
-
#billing ⇒ Object
Indicates the billing account for the user.
-
#date ⇒ Object
Account creation timestamp.
-
#default ⇒ Object
Indicates the default account for the user.
-
#id ⇒ Object
Unique identifier for account.
-
#name ⇒ Object
Name of the bank account.
-
#routing ⇒ Object
Routing number.
-
#status ⇒ Object
Current status of account.
-
#type ⇒ Object
Bank account type.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateBankResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateBankResponse
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/checkbook/models/create_bank_response.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Checkbook::CreateBankResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Checkbook::CreateBankResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account') self.account = attributes[:'account'] else self.account = nil end if attributes.key?(:'balance') self.balance = attributes[:'balance'] end if attributes.key?(:'billing') self.billing = attributes[:'billing'] else self.billing = nil end if attributes.key?(:'date') self.date = attributes[:'date'] else self.date = nil end if attributes.key?(:'default') self.default = attributes[:'default'] else self.default = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'routing') self.routing = attributes[:'routing'] else self.routing = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end end |
Instance Attribute Details
#account ⇒ Object
Last 4 of account number
19 20 21 |
# File 'lib/checkbook/models/create_bank_response.rb', line 19 def account @account end |
#balance ⇒ Object
Indicates the current amount left in the account’s balance (only for prefunded accounts)
22 23 24 |
# File 'lib/checkbook/models/create_bank_response.rb', line 22 def balance @balance end |
#billing ⇒ Object
Indicates the billing account for the user
25 26 27 |
# File 'lib/checkbook/models/create_bank_response.rb', line 25 def billing @billing end |
#date ⇒ Object
Account creation timestamp
28 29 30 |
# File 'lib/checkbook/models/create_bank_response.rb', line 28 def date @date end |
#default ⇒ Object
Indicates the default account for the user
31 32 33 |
# File 'lib/checkbook/models/create_bank_response.rb', line 31 def default @default end |
#id ⇒ Object
Unique identifier for account
34 35 36 |
# File 'lib/checkbook/models/create_bank_response.rb', line 34 def id @id end |
#name ⇒ Object
Name of the bank account
37 38 39 |
# File 'lib/checkbook/models/create_bank_response.rb', line 37 def name @name end |
#routing ⇒ Object
Routing number
40 41 42 |
# File 'lib/checkbook/models/create_bank_response.rb', line 40 def routing @routing end |
#status ⇒ Object
Current status of account
43 44 45 |
# File 'lib/checkbook/models/create_bank_response.rb', line 43 def status @status end |
#type ⇒ Object
Bank account type
46 47 48 |
# File 'lib/checkbook/models/create_bank_response.rb', line 46 def type @type end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/checkbook/models/create_bank_response.rb', line 388 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = ::Checkbook.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
87 88 89 |
# File 'lib/checkbook/models/create_bank_response.rb', line 87 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
92 93 94 |
# File 'lib/checkbook/models/create_bank_response.rb', line 92 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/checkbook/models/create_bank_response.rb', line 71 def self.attribute_map { :'account' => :'account', :'balance' => :'balance', :'billing' => :'billing', :'date' => :'date', :'default' => :'default', :'id' => :'id', :'name' => :'name', :'routing' => :'routing', :'status' => :'status', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/checkbook/models/create_bank_response.rb', line 364 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 117 118 |
# File 'lib/checkbook/models/create_bank_response.rb', line 113 def self.openapi_nullable Set.new([ :'balance', :'name', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/checkbook/models/create_bank_response.rb', line 97 def self.openapi_types { :'account' => :'String', :'balance' => :'Float', :'billing' => :'Boolean', :'date' => :'String', :'default' => :'Boolean', :'id' => :'String', :'name' => :'String', :'routing' => :'String', :'status' => :'String', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/checkbook/models/create_bank_response.rb', line 334 def ==(o) return true if self.equal?(o) self.class == o.class && account == o.account && balance == o.balance && billing == o.billing && date == o.date && default == o.default && id == o.id && name == o.name && routing == o.routing && status == o.status && type == o.type end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
459 460 461 462 463 464 465 466 467 468 469 470 471 |
# File 'lib/checkbook/models/create_bank_response.rb', line 459 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
351 352 353 |
# File 'lib/checkbook/models/create_bank_response.rb', line 351 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
357 358 359 |
# File 'lib/checkbook/models/create_bank_response.rb', line 357 def hash [account, balance, billing, date, default, id, name, routing, status, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/checkbook/models/create_bank_response.rb', line 195 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account.nil? invalid_properties.push('invalid value for "account", account cannot be nil.') end if @billing.nil? invalid_properties.push('invalid value for "billing", billing cannot be nil.') end if @date.nil? invalid_properties.push('invalid value for "date", date cannot be nil.') end if @default.nil? invalid_properties.push('invalid value for "default", default cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @routing.nil? invalid_properties.push('invalid value for "routing", routing cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
435 436 437 |
# File 'lib/checkbook/models/create_bank_response.rb', line 435 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
441 442 443 444 445 446 447 448 449 450 451 452 453 |
# File 'lib/checkbook/models/create_bank_response.rb', line 441 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
429 430 431 |
# File 'lib/checkbook/models/create_bank_response.rb', line 429 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/checkbook/models/create_bank_response.rb', line 235 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account.nil? return false if @billing.nil? return false if @date.nil? return false if @default.nil? return false if @id.nil? return false if @routing.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["PENDING", "VERIFIED", "DEPOSIT_ONLY"]) return false unless status_validator.valid?(@status) return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["CHECKING", "SAVINGS", "BUSINESS"]) return false unless type_validator.valid?(@type) true end |