Class: Checkbook::CreateDigitalCheckRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/checkbook/models/create_digital_check_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateDigitalCheckRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/checkbook/models/create_digital_check_request.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Checkbook::CreateDigitalCheckRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Checkbook::CreateDigitalCheckRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'attachment')
    self.attachment = attributes[:'attachment']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'deposit_options')
    if (value = attributes[:'deposit_options']).is_a?(Array)
      self.deposit_options = value
    end
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'number')
    self.number = attributes[:'number']
  end

  if attributes.key?(:'pin')
    self.pin = attributes[:'pin']
  end

  if attributes.key?(:'recipient')
    self.recipient = attributes[:'recipient']
  else
    self.recipient = nil
  end

  if attributes.key?(:'remittance_advice')
    if (value = attributes[:'remittance_advice']).is_a?(Array)
      self.remittance_advice = value
    end
  end
end

Instance Attribute Details

#accountObject

Debit account id for funds (if sender has multiple bank accounts)



19
20
21
# File 'lib/checkbook/models/create_digital_check_request.rb', line 19

def 
  @account
end

#amountObject

Payment amount



22
23
24
# File 'lib/checkbook/models/create_digital_check_request.rb', line 22

def amount
  @amount
end

#attachmentObject

Returns the value of attribute attachment.



24
25
26
# File 'lib/checkbook/models/create_digital_check_request.rb', line 24

def attachment
  @attachment
end

#commentObject

Comment field for payment



27
28
29
# File 'lib/checkbook/models/create_digital_check_request.rb', line 27

def comment
  @comment
end

#deposit_optionsObject

Returns the value of attribute deposit_options.



29
30
31
# File 'lib/checkbook/models/create_digital_check_request.rb', line 29

def deposit_options
  @deposit_options
end

#descriptionObject

Optional description/memo for payment



32
33
34
# File 'lib/checkbook/models/create_digital_check_request.rb', line 32

def description
  @description
end

#nameObject

Name of recipient



35
36
37
# File 'lib/checkbook/models/create_digital_check_request.rb', line 35

def name
  @name
end

#numberObject

Returns the value of attribute number.



37
38
39
# File 'lib/checkbook/models/create_digital_check_request.rb', line 37

def number
  @number
end

#pinObject

Returns the value of attribute pin.



39
40
41
# File 'lib/checkbook/models/create_digital_check_request.rb', line 39

def pin
  @pin
end

#recipientObject

Returns the value of attribute recipient.



41
42
43
# File 'lib/checkbook/models/create_digital_check_request.rb', line 41

def recipient
  @recipient
end

#remittance_adviceObject

List of the remittance records



44
45
46
# File 'lib/checkbook/models/create_digital_check_request.rb', line 44

def remittance_advice
  @remittance_advice
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/checkbook/models/create_digital_check_request.rb', line 383

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = ::Checkbook.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/checkbook/models/create_digital_check_request.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/checkbook/models/create_digital_check_request.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/checkbook/models/create_digital_check_request.rb', line 69

def self.attribute_map
  {
    :'account' => :'account',
    :'amount' => :'amount',
    :'attachment' => :'attachment',
    :'comment' => :'comment',
    :'deposit_options' => :'deposit_options',
    :'description' => :'description',
    :'name' => :'name',
    :'number' => :'number',
    :'pin' => :'pin',
    :'recipient' => :'recipient',
    :'remittance_advice' => :'remittance_advice'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/checkbook/models/create_digital_check_request.rb', line 359

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



113
114
115
116
117
118
# File 'lib/checkbook/models/create_digital_check_request.rb', line 113

def self.openapi_nullable
  Set.new([
    :'comment',
    :'description',
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/checkbook/models/create_digital_check_request.rb', line 96

def self.openapi_types
  {
    :'account' => :'String',
    :'amount' => :'Float',
    :'attachment' => :'CreateDigitalCheckRequestAttachment',
    :'comment' => :'String',
    :'deposit_options' => :'Array<String>',
    :'description' => :'String',
    :'name' => :'String',
    :'number' => :'CreateDigitalCheckRequestNumber',
    :'pin' => :'Pin',
    :'recipient' => :'CreateDigitalCheckRequestRecipient',
    :'remittance_advice' => :'Array<RemittanceAdvice>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/checkbook/models/create_digital_check_request.rb', line 328

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      amount == o.amount &&
      attachment == o.attachment &&
      comment == o.comment &&
      deposit_options == o.deposit_options &&
      description == o.description &&
      name == o.name &&
      number == o.number &&
      pin == o.pin &&
      recipient == o.recipient &&
      remittance_advice == o.remittance_advice
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/checkbook/models/create_digital_check_request.rb', line 454

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


346
347
348
# File 'lib/checkbook/models/create_digital_check_request.rb', line 346

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



352
353
354
# File 'lib/checkbook/models/create_digital_check_request.rb', line 352

def hash
  [, amount, attachment, comment, deposit_options, description, name, number, pin, recipient, remittance_advice].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/checkbook/models/create_digital_check_request.rb', line 193

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @amount < 0.01
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.01.')
  end

  if !@comment.nil? && @comment.to_s.length > 1024
    invalid_properties.push('invalid value for "comment", the character length must be smaller than or equal to 1024.')
  end

  if !@deposit_options.nil? && @deposit_options.length < 1
    invalid_properties.push('invalid value for "deposit_options", number of items must be greater than or equal to 1.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 180
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 180.')
  end

  if @name.to_s.length < 2
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 2.')
  end

  if @recipient.nil?
    invalid_properties.push('invalid value for "recipient", recipient cannot be nil.')
  end

  if !@remittance_advice.nil? && @remittance_advice.length > 50
    invalid_properties.push('invalid value for "remittance_advice", number of items must be less than or equal to 50.')
  end

  if !@remittance_advice.nil? && @remittance_advice.length < 1
    invalid_properties.push('invalid value for "remittance_advice", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



430
431
432
# File 'lib/checkbook/models/create_digital_check_request.rb', line 430

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/checkbook/models/create_digital_check_request.rb', line 436

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



424
425
426
# File 'lib/checkbook/models/create_digital_check_request.rb', line 424

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/checkbook/models/create_digital_check_request.rb', line 241

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @amount.nil?
  return false if @amount < 0.01
  return false if !@comment.nil? && @comment.to_s.length > 1024
  return false if !@deposit_options.nil? && @deposit_options.length < 1
  return false if @name.nil?
  return false if @name.to_s.length > 180
  return false if @name.to_s.length < 2
  return false if @recipient.nil?
  return false if !@remittance_advice.nil? && @remittance_advice.length > 50
  return false if !@remittance_advice.nil? && @remittance_advice.length < 1
  true
end