Class: Checkbook::CreateDirectCheckRequest
- Inherits:
-
Object
- Object
- Checkbook::CreateDirectCheckRequest
- Defined in:
- lib/checkbook/models/create_direct_check_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account ⇒ Object
Debit account id for funds (if sender has multiple bank accounts).
-
#account_number ⇒ Object
Account number.
-
#account_type ⇒ Object
Account type.
-
#amount ⇒ Object
Payment amount.
-
#attachment ⇒ Object
Returns the value of attribute attachment.
-
#comment ⇒ Object
Comment field for payment.
-
#deposit_options ⇒ Object
Returns the value of attribute deposit_options.
-
#description ⇒ Object
Optional description/memo for payment.
-
#name ⇒ Object
Name of recipient.
-
#number ⇒ Object
Returns the value of attribute number.
-
#recipient ⇒ Object
Email or text enabled phone number/id of recipient.
-
#remittance_advice ⇒ Object
List of the remittance records.
-
#routing_number ⇒ Object
Routing number.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDirectCheckRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDirectCheckRequest
Initializes the object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 134 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Checkbook::CreateDirectCheckRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Checkbook::CreateDirectCheckRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account') self.account = attributes[:'account'] end if attributes.key?(:'account_number') self.account_number = attributes[:'account_number'] else self.account_number = nil end if attributes.key?(:'account_type') self.account_type = attributes[:'account_type'] else self.account_type = nil end if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'attachment') self. = attributes[:'attachment'] end if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'deposit_options') if (value = attributes[:'deposit_options']).is_a?(Array) self. = value end end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'number') self.number = attributes[:'number'] end if attributes.key?(:'recipient') self.recipient = attributes[:'recipient'] else self.recipient = nil end if attributes.key?(:'remittance_advice') if (value = attributes[:'remittance_advice']).is_a?(Array) self.remittance_advice = value end end if attributes.key?(:'routing_number') self.routing_number = attributes[:'routing_number'] else self.routing_number = nil end end |
Instance Attribute Details
#account ⇒ Object
Debit account id for funds (if sender has multiple bank accounts)
19 20 21 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 19 def account @account end |
#account_number ⇒ Object
Account number
22 23 24 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 22 def account_number @account_number end |
#account_type ⇒ Object
Account type
25 26 27 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 25 def account_type @account_type end |
#amount ⇒ Object
Payment amount
28 29 30 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 28 def amount @amount end |
#attachment ⇒ Object
Returns the value of attribute attachment.
30 31 32 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 30 def @attachment end |
#comment ⇒ Object
Comment field for payment
33 34 35 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 33 def comment @comment end |
#deposit_options ⇒ Object
Returns the value of attribute deposit_options.
35 36 37 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 35 def @deposit_options end |
#description ⇒ Object
Optional description/memo for payment
38 39 40 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 38 def description @description end |
#name ⇒ Object
Name of recipient
41 42 43 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 41 def name @name end |
#number ⇒ Object
Returns the value of attribute number.
43 44 45 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 43 def number @number end |
#recipient ⇒ Object
Email or text enabled phone number/id of recipient
46 47 48 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 46 def recipient @recipient end |
#remittance_advice ⇒ Object
List of the remittance records
49 50 51 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 49 def remittance_advice @remittance_advice end |
#routing_number ⇒ Object
Routing number
52 53 54 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 52 def routing_number @routing_number end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 467 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = ::Checkbook.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
96 97 98 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 96 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
101 102 103 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 101 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 77 def self.attribute_map { :'account' => :'account', :'account_number' => :'account_number', :'account_type' => :'account_type', :'amount' => :'amount', :'attachment' => :'attachment', :'comment' => :'comment', :'deposit_options' => :'deposit_options', :'description' => :'description', :'name' => :'name', :'number' => :'number', :'recipient' => :'recipient', :'remittance_advice' => :'remittance_advice', :'routing_number' => :'routing_number' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 443 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
125 126 127 128 129 130 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 125 def self.openapi_nullable Set.new([ :'comment', :'description', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 106 def self.openapi_types { :'account' => :'String', :'account_number' => :'String', :'account_type' => :'String', :'amount' => :'Float', :'attachment' => :'CreateDigitalCheckRequestAttachment', :'comment' => :'String', :'deposit_options' => :'Array<String>', :'description' => :'String', :'name' => :'String', :'number' => :'CreateDirectCheckRequestNumber', :'recipient' => :'String', :'remittance_advice' => :'Array<RemittanceAdvice>', :'routing_number' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 410 def ==(o) return true if self.equal?(o) self.class == o.class && account == o.account && account_number == o.account_number && account_type == o.account_type && amount == o.amount && == o. && comment == o.comment && == o. && description == o.description && name == o.name && number == o.number && recipient == o.recipient && remittance_advice == o.remittance_advice && routing_number == o.routing_number end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
538 539 540 541 542 543 544 545 546 547 548 549 550 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 538 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
430 431 432 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 430 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
436 437 438 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 436 def hash [account, account_number, account_type, amount, , comment, , description, name, number, recipient, remittance_advice, routing_number].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 219 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_number.nil? invalid_properties.push('invalid value for "account_number", account_number cannot be nil.') end if @account_type.nil? invalid_properties.push('invalid value for "account_type", account_type cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @amount < 0.01 invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.01.') end if !@comment.nil? && @comment.to_s.length > 1024 invalid_properties.push('invalid value for "comment", the character length must be smaller than or equal to 1024.') end if !@deposit_options.nil? && @deposit_options.length < 1 invalid_properties.push('invalid value for "deposit_options", number of items must be greater than or equal to 1.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 180 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 180.') end if @name.to_s.length < 2 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 2.') end if @recipient.nil? invalid_properties.push('invalid value for "recipient", recipient cannot be nil.') end if @recipient.to_s.length > 80 invalid_properties.push('invalid value for "recipient", the character length must be smaller than or equal to 80.') end if !@remittance_advice.nil? && @remittance_advice.length > 50 invalid_properties.push('invalid value for "remittance_advice", number of items must be less than or equal to 50.') end if !@remittance_advice.nil? && @remittance_advice.length < 1 invalid_properties.push('invalid value for "remittance_advice", number of items must be greater than or equal to 1.') end if @routing_number.nil? invalid_properties.push('invalid value for "routing_number", routing_number cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
514 515 516 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 514 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
520 521 522 523 524 525 526 527 528 529 530 531 532 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 520 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
508 509 510 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 508 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/checkbook/models/create_direct_check_request.rb', line 283 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_number.nil? return false if @account_type.nil? account_type_validator = EnumAttributeValidator.new('String', ["CHECKING", "BUSINESS", "SAVINGS"]) return false unless account_type_validator.valid?(@account_type) return false if @amount.nil? return false if @amount < 0.01 return false if !@comment.nil? && @comment.to_s.length > 1024 return false if !@deposit_options.nil? && @deposit_options.length < 1 return false if @name.nil? return false if @name.to_s.length > 180 return false if @name.to_s.length < 2 return false if @recipient.nil? return false if @recipient.to_s.length > 80 return false if !@remittance_advice.nil? && @remittance_advice.length > 50 return false if !@remittance_advice.nil? && @remittance_advice.length < 1 return false if @routing_number.nil? true end |