Class: Checkbook::CreateInvoiceSubscriptionRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/checkbook/models/create_invoice_subscription_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateInvoiceSubscriptionRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Checkbook::CreateInvoiceSubscriptionRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Checkbook::CreateInvoiceSubscriptionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'duration')
    self.duration = attributes[:'duration']
  end

  if attributes.key?(:'interval')
    self.interval = attributes[:'interval']
  else
    self.interval = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'recipient')
    self.recipient = attributes[:'recipient']
  else
    self.recipient = nil
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end
end

Instance Attribute Details

#accountObject

Debit account id for funds (if sender has multiple bank accounts)



19
20
21
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 19

def 
  @account
end

#amountObject

Invoice amount



22
23
24
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 22

def amount
  @amount
end

#descriptionObject

Description for invoice



25
26
27
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 25

def description
  @description
end

#durationObject

Optional number of times the subscription should recur (defaults to indefinite)



28
29
30
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 28

def duration
  @duration
end

#intervalObject

How often the subscription will recur



31
32
33
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 31

def interval
  @interval
end

#nameObject

Name of recipient



34
35
36
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 34

def name
  @name
end

#recipientObject

Email/id of recipient



37
38
39
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 37

def recipient
  @recipient
end

#start_dateObject

Start date for subscription (this is the first date the subscription will be sent out and defaults to the current timestamp)



40
41
42
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 40

def start_date
  @start_date
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 384

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = ::Checkbook.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 65

def self.attribute_map
  {
    :'account' => :'account',
    :'amount' => :'amount',
    :'description' => :'description',
    :'duration' => :'duration',
    :'interval' => :'interval',
    :'name' => :'name',
    :'recipient' => :'recipient',
    :'start_date' => :'start_date'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 360

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
107
108
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 103

def self.openapi_nullable
  Set.new([
    :'duration',
    :'start_date'
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 89

def self.openapi_types
  {
    :'account' => :'String',
    :'amount' => :'Float',
    :'description' => :'String',
    :'duration' => :'Integer',
    :'interval' => :'String',
    :'name' => :'String',
    :'recipient' => :'String',
    :'start_date' => :'Date'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 332

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      amount == o.amount &&
      description == o.description &&
      duration == o.duration &&
      interval == o.interval &&
      name == o.name &&
      recipient == o.recipient &&
      start_date == o.start_date
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



455
456
457
458
459
460
461
462
463
464
465
466
467
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 455

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


347
348
349
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 347

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



353
354
355
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 353

def hash
  [, amount, description, duration, interval, name, recipient, start_date].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 171

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @amount < 0.01
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.01.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @description.to_s.length > 255
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.')
  end

  if !@duration.nil? && @duration > 52
    invalid_properties.push('invalid value for "duration", must be smaller than or equal to 52.')
  end

  if !@duration.nil? && @duration < 1
    invalid_properties.push('invalid value for "duration", must be greater than or equal to 1.')
  end

  if @interval.nil?
    invalid_properties.push('invalid value for "interval", interval cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 180
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 180.')
  end

  if @name.to_s.length < 2
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 2.')
  end

  if @recipient.nil?
    invalid_properties.push('invalid value for "recipient", recipient cannot be nil.')
  end

  if @recipient.to_s.length > 80
    invalid_properties.push('invalid value for "recipient", the character length must be smaller than or equal to 80.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



431
432
433
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 431

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 437

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



425
426
427
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 425

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/checkbook/models/create_invoice_subscription_request.rb', line 227

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @amount.nil?
  return false if @amount < 0.01
  return false if @description.nil?
  return false if @description.to_s.length > 255
  return false if !@duration.nil? && @duration > 52
  return false if !@duration.nil? && @duration < 1
  return false if @interval.nil?
  interval_validator = EnumAttributeValidator.new('String', ["WEEKLY", "MONTHLY"])
  return false unless interval_validator.valid?(@interval)
  return false if @name.nil?
  return false if @name.to_s.length > 180
  return false if @name.to_s.length < 2
  return false if @recipient.nil?
  return false if @recipient.to_s.length > 80
  true
end