Class: Checkbook::CreatePhysicalCheckRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/checkbook/models/create_physical_check_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreatePhysicalCheckRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/checkbook/models/create_physical_check_request.rb', line 123

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Checkbook::CreatePhysicalCheckRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Checkbook::CreatePhysicalCheckRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'attachment')
    self.attachment = attributes[:'attachment']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'mail_type')
    self.mail_type = attributes[:'mail_type']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'number')
    self.number = attributes[:'number']
  end

  if attributes.key?(:'recipient')
    self.recipient = attributes[:'recipient']
  else
    self.recipient = nil
  end

  if attributes.key?(:'remittance_advice')
    self.remittance_advice = attributes[:'remittance_advice']
  end

  if attributes.key?(:'return_address')
    self.return_address = attributes[:'return_address']
  end
end

Instance Attribute Details

#accountObject

Debit account id for funds (if sender has multiple bank accounts)



19
20
21
# File 'lib/checkbook/models/create_physical_check_request.rb', line 19

def 
  @account
end

#amountObject

Payment amount



22
23
24
# File 'lib/checkbook/models/create_physical_check_request.rb', line 22

def amount
  @amount
end

#attachmentObject

Returns the value of attribute attachment.



24
25
26
# File 'lib/checkbook/models/create_physical_check_request.rb', line 24

def attachment
  @attachment
end

#commentObject

Comment field for payment



27
28
29
# File 'lib/checkbook/models/create_physical_check_request.rb', line 27

def comment
  @comment
end

#descriptionObject

Optional description/memo for payment



30
31
32
# File 'lib/checkbook/models/create_physical_check_request.rb', line 30

def description
  @description
end

#mail_typeObject

Delivery options



33
34
35
# File 'lib/checkbook/models/create_physical_check_request.rb', line 33

def mail_type
  @mail_type
end

#nameObject

Name of recipient



36
37
38
# File 'lib/checkbook/models/create_physical_check_request.rb', line 36

def name
  @name
end

#numberObject

Returns the value of attribute number.



38
39
40
# File 'lib/checkbook/models/create_physical_check_request.rb', line 38

def number
  @number
end

#recipientObject

Returns the value of attribute recipient.



40
41
42
# File 'lib/checkbook/models/create_physical_check_request.rb', line 40

def recipient
  @recipient
end

#remittance_adviceObject

Returns the value of attribute remittance_advice.



42
43
44
# File 'lib/checkbook/models/create_physical_check_request.rb', line 42

def remittance_advice
  @remittance_advice
end

#return_addressObject

Returns the value of attribute return_address.



44
45
46
# File 'lib/checkbook/models/create_physical_check_request.rb', line 44

def return_address
  @return_address
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/checkbook/models/create_physical_check_request.rb', line 359

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = ::Checkbook.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/checkbook/models/create_physical_check_request.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/checkbook/models/create_physical_check_request.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/checkbook/models/create_physical_check_request.rb', line 69

def self.attribute_map
  {
    :'account' => :'account',
    :'amount' => :'amount',
    :'attachment' => :'attachment',
    :'comment' => :'comment',
    :'description' => :'description',
    :'mail_type' => :'mail_type',
    :'name' => :'name',
    :'number' => :'number',
    :'recipient' => :'recipient',
    :'remittance_advice' => :'remittance_advice',
    :'return_address' => :'return_address'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/checkbook/models/create_physical_check_request.rb', line 335

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



113
114
115
116
117
118
119
# File 'lib/checkbook/models/create_physical_check_request.rb', line 113

def self.openapi_nullable
  Set.new([
    :'comment',
    :'description',
    :'mail_type',
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/checkbook/models/create_physical_check_request.rb', line 96

def self.openapi_types
  {
    :'account' => :'String',
    :'amount' => :'Float',
    :'attachment' => :'CreateDigitalCheckRequestAttachment',
    :'comment' => :'String',
    :'description' => :'String',
    :'mail_type' => :'String',
    :'name' => :'String',
    :'number' => :'CreatePhysicalCheckRequestNumber',
    :'recipient' => :'PhysicalCheckRecipient',
    :'remittance_advice' => :'CreatePhysicalCheckRequestRemittanceAdvice',
    :'return_address' => :'PhysicalCheckRecipient'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/checkbook/models/create_physical_check_request.rb', line 304

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      amount == o.amount &&
      attachment == o.attachment &&
      comment == o.comment &&
      description == o.description &&
      mail_type == o.mail_type &&
      name == o.name &&
      number == o.number &&
      recipient == o.recipient &&
      remittance_advice == o.remittance_advice &&
      return_address == o.return_address
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/checkbook/models/create_physical_check_request.rb', line 430

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


322
323
324
# File 'lib/checkbook/models/create_physical_check_request.rb', line 322

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



328
329
330
# File 'lib/checkbook/models/create_physical_check_request.rb', line 328

def hash
  [, amount, attachment, comment, description, mail_type, name, number, recipient, remittance_advice, return_address].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/checkbook/models/create_physical_check_request.rb', line 190

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @amount < 0.01
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.01.')
  end

  if !@comment.nil? && @comment.to_s.length > 1024
    invalid_properties.push('invalid value for "comment", the character length must be smaller than or equal to 1024.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 180
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 180.')
  end

  if @name.to_s.length < 2
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 2.')
  end

  if @recipient.nil?
    invalid_properties.push('invalid value for "recipient", recipient cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



406
407
408
# File 'lib/checkbook/models/create_physical_check_request.rb', line 406

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/checkbook/models/create_physical_check_request.rb', line 412

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



400
401
402
# File 'lib/checkbook/models/create_physical_check_request.rb', line 400

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/checkbook/models/create_physical_check_request.rb', line 226

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @amount.nil?
  return false if @amount < 0.01
  return false if !@comment.nil? && @comment.to_s.length > 1024
  mail_type_validator = EnumAttributeValidator.new('String', ["USPS_FIRST_CLASS", "OVERNIGHT", "TWO_DAY", "USPS_CERTIFIED"])
  return false unless mail_type_validator.valid?(@mail_type)
  return false if @name.nil?
  return false if @name.to_s.length > 180
  return false if @name.to_s.length < 2
  return false if @recipient.nil?
  true
end