Class: Checkbook::CsvCheckRequest
- Inherits:
-
Object
- Object
- Checkbook::CsvCheckRequest
- Defined in:
- lib/checkbook/models/csv_check_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account ⇒ Object
Optional credit account id for funds (if user has multiple bank accounts).
-
#file ⇒ Object
List of CSV rows.
-
#mail_type ⇒ Object
Mail delivery option.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CsvCheckRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CsvCheckRequest
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/checkbook/models/csv_check_request.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Checkbook::CsvCheckRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Checkbook::CsvCheckRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account') self.account = attributes[:'account'] end if attributes.key?(:'file') if (value = attributes[:'file']).is_a?(Array) self.file = value end else self.file = nil end if attributes.key?(:'mail_type') self.mail_type = attributes[:'mail_type'] end end |
Instance Attribute Details
#account ⇒ Object
Optional credit account id for funds (if user has multiple bank accounts)
19 20 21 |
# File 'lib/checkbook/models/csv_check_request.rb', line 19 def account @account end |
#file ⇒ Object
List of CSV rows
22 23 24 |
# File 'lib/checkbook/models/csv_check_request.rb', line 22 def file @file end |
#mail_type ⇒ Object
Mail delivery option
25 26 27 |
# File 'lib/checkbook/models/csv_check_request.rb', line 25 def mail_type @mail_type end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/checkbook/models/csv_check_request.rb', line 226 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = ::Checkbook.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/checkbook/models/csv_check_request.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/checkbook/models/csv_check_request.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 |
# File 'lib/checkbook/models/csv_check_request.rb', line 50 def self.attribute_map { :'account' => :'account', :'file' => :'file', :'mail_type' => :'mail_type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/checkbook/models/csv_check_request.rb', line 202 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 82 |
# File 'lib/checkbook/models/csv_check_request.rb', line 78 def self.openapi_nullable Set.new([ :'mail_type' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 |
# File 'lib/checkbook/models/csv_check_request.rb', line 69 def self.openapi_types { :'account' => :'String', :'file' => :'Array<FileRow>', :'mail_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
179 180 181 182 183 184 185 |
# File 'lib/checkbook/models/csv_check_request.rb', line 179 def ==(o) return true if self.equal?(o) self.class == o.class && account == o.account && file == o.file && mail_type == o.mail_type end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/checkbook/models/csv_check_request.rb', line 297 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
189 190 191 |
# File 'lib/checkbook/models/csv_check_request.rb', line 189 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
195 196 197 |
# File 'lib/checkbook/models/csv_check_request.rb', line 195 def hash [account, file, mail_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/checkbook/models/csv_check_request.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @file.nil? invalid_properties.push('invalid value for "file", file cannot be nil.') end if @file.length > 1500 invalid_properties.push('invalid value for "file", number of items must be less than or equal to 1500.') end if @file.length < 1 invalid_properties.push('invalid value for "file", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
273 274 275 |
# File 'lib/checkbook/models/csv_check_request.rb', line 273 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/checkbook/models/csv_check_request.rb', line 279 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
267 268 269 |
# File 'lib/checkbook/models/csv_check_request.rb', line 267 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
139 140 141 142 143 144 145 146 147 |
# File 'lib/checkbook/models/csv_check_request.rb', line 139 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @file.nil? return false if @file.length > 1500 return false if @file.length < 1 mail_type_validator = EnumAttributeValidator.new('String', ["USPS_FIRST_CLASS", "OVERNIGHT", "TWO_DAY", "USPS_CERTIFIED"]) return false unless mail_type_validator.valid?(@mail_type) true end |