Class: Checkbook::GetInvoiceResponse
- Inherits:
-
Object
- Object
- Checkbook::GetInvoiceResponse
- Defined in:
- lib/checkbook/models/get_invoice_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
Invoice amount.
-
#attachment_uri ⇒ Object
URI for invoice attachment.
-
#check_id ⇒ Object
Associated check number.
-
#date ⇒ Object
Invoice creation timestamp.
-
#description ⇒ Object
Invoice description.
-
#direction ⇒ Object
Direction.
-
#id ⇒ Object
Unique identifier for invoice.
-
#name ⇒ Object
Name of third party who sent/received the invoice.
-
#number ⇒ Object
Invoice number.
-
#recipient ⇒ Object
Email/id of the invoice recipient.
-
#status ⇒ Object
Current status of the invoice.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetInvoiceResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ GetInvoiceResponse
Initializes the object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 129 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Checkbook::GetInvoiceResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Checkbook::GetInvoiceResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'attachment_uri') self. = attributes[:'attachment_uri'] end if attributes.key?(:'check_id') self.check_id = attributes[:'check_id'] end if attributes.key?(:'date') self.date = attributes[:'date'] else self.date = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'direction') self.direction = attributes[:'direction'] else self.direction = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'number') self.number = attributes[:'number'] else self.number = nil end if attributes.key?(:'recipient') self.recipient = attributes[:'recipient'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end end |
Instance Attribute Details
#amount ⇒ Object
Invoice amount
19 20 21 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 19 def amount @amount end |
#attachment_uri ⇒ Object
URI for invoice attachment
22 23 24 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 22 def @attachment_uri end |
#check_id ⇒ Object
Associated check number
25 26 27 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 25 def check_id @check_id end |
#date ⇒ Object
Invoice creation timestamp
28 29 30 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 28 def date @date end |
#description ⇒ Object
Invoice description
31 32 33 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 31 def description @description end |
#direction ⇒ Object
Direction
34 35 36 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 34 def direction @direction end |
#id ⇒ Object
Unique identifier for invoice
37 38 39 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 37 def id @id end |
#name ⇒ Object
Name of third party who sent/received the invoice
40 41 42 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 40 def name @name end |
#number ⇒ Object
Invoice number
43 44 45 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 43 def number @number end |
#recipient ⇒ Object
Email/id of the invoice recipient
46 47 48 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 46 def recipient @recipient end |
#status ⇒ Object
Current status of the invoice
49 50 51 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 49 def status @status end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 381 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = ::Checkbook.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
91 92 93 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 91 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 96 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 74 def self.attribute_map { :'amount' => :'amount', :'attachment_uri' => :'attachment_uri', :'check_id' => :'check_id', :'date' => :'date', :'description' => :'description', :'direction' => :'direction', :'id' => :'id', :'name' => :'name', :'number' => :'number', :'recipient' => :'recipient', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 357 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
118 119 120 121 122 123 124 125 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 118 def self.openapi_nullable Set.new([ :'attachment_uri', :'check_id', :'name', :'recipient', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 101 def self.openapi_types { :'amount' => :'Float', :'attachment_uri' => :'String', :'check_id' => :'String', :'date' => :'String', :'description' => :'String', :'direction' => :'String', :'id' => :'String', :'name' => :'String', :'number' => :'String', :'recipient' => :'String', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 326 def ==(o) return true if self.equal?(o) self.class == o.class && amount == o.amount && == o. && check_id == o.check_id && date == o.date && description == o.description && direction == o.direction && id == o.id && name == o.name && number == o.number && recipient == o.recipient && status == o.status end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
452 453 454 455 456 457 458 459 460 461 462 463 464 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 452 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
344 345 346 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 344 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
350 351 352 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 350 def hash [amount, , check_id, date, description, direction, id, name, number, recipient, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 204 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @date.nil? invalid_properties.push('invalid value for "date", date cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @direction.nil? invalid_properties.push('invalid value for "direction", direction cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @number.nil? invalid_properties.push('invalid value for "number", number cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
428 429 430 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 428 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
434 435 436 437 438 439 440 441 442 443 444 445 446 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 434 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
422 423 424 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 422 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/checkbook/models/get_invoice_response.rb', line 240 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @amount.nil? return false if @date.nil? return false if @description.nil? return false if @direction.nil? direction_validator = EnumAttributeValidator.new('String', ["INCOMING", "OUTGOING"]) return false unless direction_validator.valid?(@direction) return false if @id.nil? return false if @number.nil? return false if @status.nil? true end |