Class: Checkbook::Merchant

Inherits:
Object
  • Object
show all
Defined in:
lib/checkbook/models/merchant.rb

Overview

Merchant fields

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Merchant

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/checkbook/models/merchant.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Checkbook::Merchant` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Checkbook::Merchant`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'incorporation_date')
    self.incorporation_date = attributes[:'incorporation_date']
  end

  if attributes.key?(:'industry')
    self.industry = attributes[:'industry']
  end

  if attributes.key?(:'legal_firstname')
    self.legal_firstname = attributes[:'legal_firstname']
  end

  if attributes.key?(:'legal_lastname')
    self.legal_lastname = attributes[:'legal_lastname']
  end

  if attributes.key?(:'principal_address')
    self.principal_address = attributes[:'principal_address']
  end

  if attributes.key?(:'principal_citizenship_status')
    self.principal_citizenship_status = attributes[:'principal_citizenship_status']
  end

  if attributes.key?(:'principal_occupation')
    self.principal_occupation = attributes[:'principal_occupation']
  end

  if attributes.key?(:'tax_id')
    self.tax_id = attributes[:'tax_id']
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



19
20
21
# File 'lib/checkbook/models/merchant.rb', line 19

def address
  @address
end

#incorporation_dateObject

Business incorporation or formation date



22
23
24
# File 'lib/checkbook/models/merchant.rb', line 22

def incorporation_date
  @incorporation_date
end

#industryObject

Industry sector



25
26
27
# File 'lib/checkbook/models/merchant.rb', line 25

def industry
  @industry
end

Principal officer first name



28
29
30
# File 'lib/checkbook/models/merchant.rb', line 28

def legal_firstname
  @legal_firstname
end

Principal officer last name



31
32
33
# File 'lib/checkbook/models/merchant.rb', line 31

def legal_lastname
  @legal_lastname
end

#principal_addressObject

Returns the value of attribute principal_address.



33
34
35
# File 'lib/checkbook/models/merchant.rb', line 33

def principal_address
  @principal_address
end

#principal_citizenship_statusObject

One of a standard set of values that indicate the citizenship status



36
37
38
# File 'lib/checkbook/models/merchant.rb', line 36

def principal_citizenship_status
  @principal_citizenship_status
end

#principal_occupationObject

Occupation of principal



39
40
41
# File 'lib/checkbook/models/merchant.rb', line 39

def principal_occupation
  @principal_occupation
end

#tax_idObject

Tax ID



42
43
44
# File 'lib/checkbook/models/merchant.rb', line 42

def tax_id
  @tax_id
end

#websiteObject

Company website



45
46
47
# File 'lib/checkbook/models/merchant.rb', line 45

def website
  @website
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/checkbook/models/merchant.rb', line 360

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = ::Checkbook.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/checkbook/models/merchant.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/checkbook/models/merchant.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/checkbook/models/merchant.rb', line 70

def self.attribute_map
  {
    :'address' => :'address',
    :'incorporation_date' => :'incorporation_date',
    :'industry' => :'industry',
    :'legal_firstname' => :'legal_firstname',
    :'legal_lastname' => :'legal_lastname',
    :'principal_address' => :'principal_address',
    :'principal_citizenship_status' => :'principal_citizenship_status',
    :'principal_occupation' => :'principal_occupation',
    :'tax_id' => :'tax_id',
    :'website' => :'website'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/checkbook/models/merchant.rb', line 336

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
116
117
118
119
120
121
122
# File 'lib/checkbook/models/merchant.rb', line 112

def self.openapi_nullable
  Set.new([
    :'industry',
    :'legal_firstname',
    :'legal_lastname',
    :'principal_citizenship_status',
    :'principal_occupation',
    :'tax_id',
    :'website'
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/checkbook/models/merchant.rb', line 96

def self.openapi_types
  {
    :'address' => :'UpdateMerchantAddress',
    :'incorporation_date' => :'Date',
    :'industry' => :'Integer',
    :'legal_firstname' => :'String',
    :'legal_lastname' => :'String',
    :'principal_address' => :'UpdatePrincipalAddress',
    :'principal_citizenship_status' => :'String',
    :'principal_occupation' => :'String',
    :'tax_id' => :'String',
    :'website' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/checkbook/models/merchant.rb', line 306

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      address == o.address &&
      incorporation_date == o.incorporation_date &&
      industry == o.industry &&
      legal_firstname == o.legal_firstname &&
      legal_lastname == o.legal_lastname &&
      principal_address == o.principal_address &&
      principal_citizenship_status == o.principal_citizenship_status &&
      principal_occupation == o.principal_occupation &&
      tax_id == o.tax_id &&
      website == o.website
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/checkbook/models/merchant.rb', line 431

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


323
324
325
# File 'lib/checkbook/models/merchant.rb', line 323

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



329
330
331
# File 'lib/checkbook/models/merchant.rb', line 329

def hash
  [address, incorporation_date, industry, legal_firstname, legal_lastname, principal_address, principal_citizenship_status, principal_occupation, tax_id, website].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/checkbook/models/merchant.rb', line 183

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@legal_firstname.nil? && @legal_firstname.to_s.length > 64
    invalid_properties.push('invalid value for "legal_firstname", the character length must be smaller than or equal to 64.')
  end

  if !@legal_lastname.nil? && @legal_lastname.to_s.length > 64
    invalid_properties.push('invalid value for "legal_lastname", the character length must be smaller than or equal to 64.')
  end

  if !@principal_occupation.nil? && @principal_occupation.to_s.length > 40
    invalid_properties.push('invalid value for "principal_occupation", the character length must be smaller than or equal to 40.')
  end

  if !@tax_id.nil? && @tax_id.to_s.length > 9
    invalid_properties.push('invalid value for "tax_id", the character length must be smaller than or equal to 9.')
  end

  if !@tax_id.nil? && @tax_id.to_s.length < 9
    invalid_properties.push('invalid value for "tax_id", the character length must be greater than or equal to 9.')
  end

  if !@website.nil? && @website.to_s.length > 100
    invalid_properties.push('invalid value for "website", the character length must be smaller than or equal to 100.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



407
408
409
# File 'lib/checkbook/models/merchant.rb', line 407

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/checkbook/models/merchant.rb', line 413

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



401
402
403
# File 'lib/checkbook/models/merchant.rb', line 401

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/checkbook/models/merchant.rb', line 215

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  industry_validator = EnumAttributeValidator.new('Integer', [11, 21, 22, 23, 33, 42, 45, 49, 51, 52, 53, 54, 55, 56, 61, 62, 71, 72, 81, 92, 441, 519, 524, 624, 4541, 5411, 5614, 54112, 541211, 541214, 541614])
  return false unless industry_validator.valid?(@industry)
  return false if !@legal_firstname.nil? && @legal_firstname.to_s.length > 64
  return false if !@legal_lastname.nil? && @legal_lastname.to_s.length > 64
  principal_citizenship_status_validator = EnumAttributeValidator.new('String', ["us_citizen", "resident", "non_resident"])
  return false unless principal_citizenship_status_validator.valid?(@principal_citizenship_status)
  return false if !@principal_occupation.nil? && @principal_occupation.to_s.length > 40
  return false if !@tax_id.nil? && @tax_id.to_s.length > 9
  return false if !@tax_id.nil? && @tax_id.to_s.length < 9
  return false if !@website.nil? && @website.to_s.length > 100
  true
end