Class: Checkbook::MultiFileRow

Inherits:
Object
  • Object
show all
Defined in:
lib/checkbook/models/multi_file_row.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MultiFileRow

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/checkbook/models/multi_file_row.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Checkbook::MultiFileRow` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Checkbook::MultiFileRow`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'address_1')
    self.address_1 = attributes[:'address_1']
  else
    self.address_1 = nil
  end

  if attributes.key?(:'address_2')
    self.address_2 = attributes[:'address_2']
  else
    self.address_2 = nil
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'name_1')
    self.name_1 = attributes[:'name_1']
  else
    self.name_1 = nil
  end

  if attributes.key?(:'name_2')
    self.name_2 = attributes[:'name_2']
  else
    self.name_2 = nil
  end

  if attributes.key?(:'number')
    self.number = attributes[:'number']
  end
end

Instance Attribute Details

#address_1Object

Email/id of the recipient 1



19
20
21
# File 'lib/checkbook/models/multi_file_row.rb', line 19

def address_1
  @address_1
end

#address_2Object

Email/id of the recipient 2



22
23
24
# File 'lib/checkbook/models/multi_file_row.rb', line 22

def address_2
  @address_2
end

#amountObject

Check amount



25
26
27
# File 'lib/checkbook/models/multi_file_row.rb', line 25

def amount
  @amount
end

#descriptionObject

Check description



28
29
30
# File 'lib/checkbook/models/multi_file_row.rb', line 28

def description
  @description
end

#name_1Object

Name of recipient 1



31
32
33
# File 'lib/checkbook/models/multi_file_row.rb', line 31

def name_1
  @name_1
end

#name_2Object

Name of recipient 2



34
35
36
# File 'lib/checkbook/models/multi_file_row.rb', line 34

def name_2
  @name_2
end

#numberObject

Check number



37
38
39
# File 'lib/checkbook/models/multi_file_row.rb', line 37

def number
  @number
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/checkbook/models/multi_file_row.rb', line 344

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = ::Checkbook.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/checkbook/models/multi_file_row.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/checkbook/models/multi_file_row.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/checkbook/models/multi_file_row.rb', line 40

def self.attribute_map
  {
    :'address_1' => :'address_1',
    :'address_2' => :'address_2',
    :'amount' => :'amount',
    :'description' => :'description',
    :'name_1' => :'name_1',
    :'name_2' => :'name_2',
    :'number' => :'number'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/checkbook/models/multi_file_row.rb', line 320

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
80
81
# File 'lib/checkbook/models/multi_file_row.rb', line 76

def self.openapi_nullable
  Set.new([
    :'description',
    :'number'
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/checkbook/models/multi_file_row.rb', line 63

def self.openapi_types
  {
    :'address_1' => :'String',
    :'address_2' => :'String',
    :'amount' => :'Float',
    :'description' => :'String',
    :'name_1' => :'String',
    :'name_2' => :'String',
    :'number' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



293
294
295
296
297
298
299
300
301
302
303
# File 'lib/checkbook/models/multi_file_row.rb', line 293

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      address_1 == o.address_1 &&
      address_2 == o.address_2 &&
      amount == o.amount &&
      description == o.description &&
      name_1 == o.name_1 &&
      name_2 == o.name_2 &&
      number == o.number
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/checkbook/models/multi_file_row.rb', line 415

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


307
308
309
# File 'lib/checkbook/models/multi_file_row.rb', line 307

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



313
314
315
# File 'lib/checkbook/models/multi_file_row.rb', line 313

def hash
  [address_1, address_2, amount, description, name_1, name_2, number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/checkbook/models/multi_file_row.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @address_1.nil?
    invalid_properties.push('invalid value for "address_1", address_1 cannot be nil.')
  end

  if @address_1.to_s.length > 80
    invalid_properties.push('invalid value for "address_1", the character length must be smaller than or equal to 80.')
  end

  if @address_2.nil?
    invalid_properties.push('invalid value for "address_2", address_2 cannot be nil.')
  end

  if @address_2.to_s.length > 80
    invalid_properties.push('invalid value for "address_2", the character length must be smaller than or equal to 80.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @amount < 0.01
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.01.')
  end

  if @name_1.nil?
    invalid_properties.push('invalid value for "name_1", name_1 cannot be nil.')
  end

  if @name_1.to_s.length > 180
    invalid_properties.push('invalid value for "name_1", the character length must be smaller than or equal to 180.')
  end

  if @name_1.to_s.length < 2
    invalid_properties.push('invalid value for "name_1", the character length must be greater than or equal to 2.')
  end

  if @name_2.nil?
    invalid_properties.push('invalid value for "name_2", name_2 cannot be nil.')
  end

  if @name_2.to_s.length > 180
    invalid_properties.push('invalid value for "name_2", the character length must be smaller than or equal to 180.')
  end

  if @name_2.to_s.length < 2
    invalid_properties.push('invalid value for "name_2", the character length must be greater than or equal to 2.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



391
392
393
# File 'lib/checkbook/models/multi_file_row.rb', line 391

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/checkbook/models/multi_file_row.rb', line 397

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



385
386
387
# File 'lib/checkbook/models/multi_file_row.rb', line 385

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/checkbook/models/multi_file_row.rb', line 196

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @address_1.nil?
  return false if @address_1.to_s.length > 80
  return false if @address_2.nil?
  return false if @address_2.to_s.length > 80
  return false if @amount.nil?
  return false if @amount < 0.01
  return false if @name_1.nil?
  return false if @name_1.to_s.length > 180
  return false if @name_1.to_s.length < 2
  return false if @name_2.nil?
  return false if @name_2.to_s.length > 180
  return false if @name_2.to_s.length < 2
  true
end