Class: Checkbook::Subscription

Inherits:
Object
  • Object
show all
Defined in:
lib/checkbook/api/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ Subscription

Returns a new instance of Subscription.



19
20
21
# File 'lib/checkbook/api/subscription.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/checkbook/api/subscription.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#delete_subscription(subscription_id, opts = {}) ⇒ nil

Remove subscription Remove the specified subscription

Parameters:

  • subscription_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


27
28
29
30
# File 'lib/checkbook/api/subscription.rb', line 27

def delete_subscription(subscription_id, opts = {})
  delete_subscription_with_http_info(subscription_id, opts)
  nil
end

#delete_subscription_with_http_info(subscription_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Remove subscription Remove the specified subscription

Parameters:

  • subscription_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/checkbook/api/subscription.rb', line 37

def delete_subscription_with_http_info(subscription_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: Subscription.delete_subscription ...'
  end
  # verify the required parameter 'subscription_id' is set
  if @api_client.config.client_side_validation && subscription_id.nil?
    fail ArgumentError, "Missing the required parameter 'subscription_id' when calling Subscription.delete_subscription"
  end
  # resource path
  local_var_path = '/v3/subscription/{subscription_id}'.sub('{' + 'subscription_id' + '}', CGI.escape(subscription_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"Subscription.delete_subscription",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: Subscription#delete_subscription\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_subscription(subscription_id, opts = {}) ⇒ GetSubscriptionResponse

Get subscription Get the specified subscription

Parameters:

  • subscription_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



90
91
92
93
# File 'lib/checkbook/api/subscription.rb', line 90

def get_subscription(subscription_id, opts = {})
  data, _status_code, _headers = get_subscription_with_http_info(subscription_id, opts)
  data
end

#get_subscription_with_http_info(subscription_id, opts = {}) ⇒ Array<(GetSubscriptionResponse, Integer, Hash)>

Get subscription Get the specified subscription

Parameters:

  • subscription_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetSubscriptionResponse, Integer, Hash)>)

    GetSubscriptionResponse data, response status code and response headers



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/checkbook/api/subscription.rb', line 100

def get_subscription_with_http_info(subscription_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: Subscription.get_subscription ...'
  end
  # verify the required parameter 'subscription_id' is set
  if @api_client.config.client_side_validation && subscription_id.nil?
    fail ArgumentError, "Missing the required parameter 'subscription_id' when calling Subscription.get_subscription"
  end
  # resource path
  local_var_path = '/v3/subscription/{subscription_id}'.sub('{' + 'subscription_id' + '}', CGI.escape(subscription_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSubscriptionResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"Subscription.get_subscription",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: Subscription#get_subscription\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_subscriptions(opts = {}) ⇒ GetSubscriptionsResponse

Get subscriptions Return the subscriptions

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :direction (String)

    Direction

  • :end_date (Date)

    End date

  • :page (Integer)

    Page number (default to 1)

  • :per_page (Integer)

    Items per page (default to 50)

  • :q (String)

    Query

  • :sort (String)

    Sort

  • :start_date (Date)

    Start date

  • :status (String)

    Status

Returns:



160
161
162
163
# File 'lib/checkbook/api/subscription.rb', line 160

def get_subscriptions(opts = {})
  data, _status_code, _headers = get_subscriptions_with_http_info(opts)
  data
end

#get_subscriptions_with_http_info(opts = {}) ⇒ Array<(GetSubscriptionsResponse, Integer, Hash)>

Get subscriptions Return the subscriptions

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :direction (String)

    Direction

  • :end_date (Date)

    End date

  • :page (Integer)

    Page number (default to 1)

  • :per_page (Integer)

    Items per page (default to 50)

  • :q (String)

    Query

  • :sort (String)

    Sort

  • :start_date (Date)

    Start date

  • :status (String)

    Status

Returns:

  • (Array<(GetSubscriptionsResponse, Integer, Hash)>)

    GetSubscriptionsResponse data, response status code and response headers



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/checkbook/api/subscription.rb', line 177

def get_subscriptions_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: Subscription.get_subscriptions ...'
  end
  allowable_values = ["INCOMING", "OUTGOING"]
  if @api_client.config.client_side_validation && opts[:'direction'] && !allowable_values.include?(opts[:'direction'])
    fail ArgumentError, "invalid value for \"direction\", must be one of #{allowable_values}"
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling Subscription.get_subscriptions, must be greater than or equal to 1.'
  end

  allowable_values = [10, 25, 50, 100, 250]
  if @api_client.config.client_side_validation && opts[:'per_page'] && !allowable_values.include?(opts[:'per_page'])
    fail ArgumentError, "invalid value for \"per_page\", must be one of #{allowable_values}"
  end
  if @api_client.config.client_side_validation && !opts[:'q'].nil? && opts[:'q'].to_s.length > 180
    fail ArgumentError, 'invalid value for "opts[:"q"]" when calling Subscription.get_subscriptions, the character length must be smaller than or equal to 180.'
  end

  allowable_values = ["+NUMBER", "-NUMBER", "+TYPE", "-TYPE", "+AMOUNT", "-AMOUNT", "+STATUS", "-STATUS", "+DATE", "-DATE", "+UPDATE", "-UPDATE", "+DESCRIPTION", "-DESCRIPTION"]
  if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort'])
    fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}"
  end
  allowable_values = ["PAID", "IN_PROCESS", "UNPAID", "VOID", "EXPIRED", "PRINTED", "MAILED", "FAILED", "REFUNDED"]
  if @api_client.config.client_side_validation && opts[:'status'] && !allowable_values.include?(opts[:'status'])
    fail ArgumentError, "invalid value for \"status\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/v3/subscription'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'direction'] = opts[:'direction'] if !opts[:'direction'].nil?
  query_params[:'end_date'] = opts[:'end_date'] if !opts[:'end_date'].nil?
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'start_date'] = opts[:'start_date'] if !opts[:'start_date'].nil?
  query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSubscriptionsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"Subscription.get_subscriptions",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: Subscription#get_subscriptions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_subscription_check(create_check_subscription_request, opts = {}) ⇒ CreateSubscriptionResponse

Create payment subscription Create a new payment subscription

Parameters:

Returns:



258
259
260
261
# File 'lib/checkbook/api/subscription.rb', line 258

def post_subscription_check(create_check_subscription_request, opts = {})
  data, _status_code, _headers = post_subscription_check_with_http_info(create_check_subscription_request, opts)
  data
end

#post_subscription_check_with_http_info(create_check_subscription_request, opts = {}) ⇒ Array<(CreateSubscriptionResponse, Integer, Hash)>

Create payment subscription Create a new payment subscription

Parameters:

Returns:

  • (Array<(CreateSubscriptionResponse, Integer, Hash)>)

    CreateSubscriptionResponse data, response status code and response headers



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/checkbook/api/subscription.rb', line 268

def post_subscription_check_with_http_info(create_check_subscription_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: Subscription.post_subscription_check ...'
  end
  # verify the required parameter 'create_check_subscription_request' is set
  if @api_client.config.client_side_validation && create_check_subscription_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_check_subscription_request' when calling Subscription.post_subscription_check"
  end
  # resource path
  local_var_path = '/v3/subscription/check'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_check_subscription_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CreateSubscriptionResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"Subscription.post_subscription_check",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: Subscription#post_subscription_check\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_subscription_invoice(create_invoice_subscription_request, opts = {}) ⇒ CreateSubscriptionResponse

Create invoice subscription Create a new invoice subscription

Parameters:

Returns:



326
327
328
329
# File 'lib/checkbook/api/subscription.rb', line 326

def post_subscription_invoice(create_invoice_subscription_request, opts = {})
  data, _status_code, _headers = post_subscription_invoice_with_http_info(create_invoice_subscription_request, opts)
  data
end

#post_subscription_invoice_with_http_info(create_invoice_subscription_request, opts = {}) ⇒ Array<(CreateSubscriptionResponse, Integer, Hash)>

Create invoice subscription Create a new invoice subscription

Parameters:

Returns:

  • (Array<(CreateSubscriptionResponse, Integer, Hash)>)

    CreateSubscriptionResponse data, response status code and response headers



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/checkbook/api/subscription.rb', line 336

def post_subscription_invoice_with_http_info(create_invoice_subscription_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: Subscription.post_subscription_invoice ...'
  end
  # verify the required parameter 'create_invoice_subscription_request' is set
  if @api_client.config.client_side_validation && create_invoice_subscription_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_invoice_subscription_request' when calling Subscription.post_subscription_invoice"
  end
  # resource path
  local_var_path = '/v3/subscription/invoice'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_invoice_subscription_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CreateSubscriptionResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"Subscription.post_subscription_invoice",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: Subscription#post_subscription_invoice\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#put_subscription(subscription_id, update_subscription_request, opts = {}) ⇒ nil

Update subscription Update the specified subscription

Parameters:

  • subscription_id (String)
  • update_subscription_request (UpdateSubscriptionRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


395
396
397
398
# File 'lib/checkbook/api/subscription.rb', line 395

def put_subscription(subscription_id, update_subscription_request, opts = {})
  put_subscription_with_http_info(subscription_id, update_subscription_request, opts)
  nil
end

#put_subscription_with_http_info(subscription_id, update_subscription_request, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Update subscription Update the specified subscription

Parameters:

  • subscription_id (String)
  • update_subscription_request (UpdateSubscriptionRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/checkbook/api/subscription.rb', line 406

def put_subscription_with_http_info(subscription_id, update_subscription_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: Subscription.put_subscription ...'
  end
  # verify the required parameter 'subscription_id' is set
  if @api_client.config.client_side_validation && subscription_id.nil?
    fail ArgumentError, "Missing the required parameter 'subscription_id' when calling Subscription.put_subscription"
  end
  # verify the required parameter 'update_subscription_request' is set
  if @api_client.config.client_side_validation && update_subscription_request.nil?
    fail ArgumentError, "Missing the required parameter 'update_subscription_request' when calling Subscription.put_subscription"
  end
  # resource path
  local_var_path = '/v3/subscription/{subscription_id}'.sub('{' + 'subscription_id' + '}', CGI.escape(subscription_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(update_subscription_request)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['token']

  new_options = opts.merge(
    :operation => :"Subscription.put_subscription",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: Subscription#put_subscription\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end