Class: Checkbook::Checkbook
- Inherits:
-
Object
- Object
- Checkbook::Checkbook
- Defined in:
- lib/checkbook/api/checkbook.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#delete_checkbook(checkbook_id, opts = {}) ⇒ nil
Cancel a checkbook Cancel the specified checkbook order.
-
#delete_checkbook_with_http_info(checkbook_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Cancel a checkbook Cancel the specified checkbook order.
-
#get_checkbook(checkbook_id, opts = {}) ⇒ GetCheckbookResponse
Get checkbook Get the specified checkbook.
-
#get_checkbook_tracking(checkbook_id, opts = {}) ⇒ GetCheckbookTrackingResponseExpress
Get tracking details on checkbooks Get tracking details on checkbook.
-
#get_checkbook_tracking_with_http_info(checkbook_id, opts = {}) ⇒ Array<(GetCheckbookTrackingResponseExpress, Integer, Hash)>
Get tracking details on checkbooks Get tracking details on checkbook.
-
#get_checkbook_with_http_info(checkbook_id, opts = {}) ⇒ Array<(GetCheckbookResponse, Integer, Hash)>
Get checkbook Get the specified checkbook.
-
#get_checkbooks(opts = {}) ⇒ GetCheckbooksResponse
Get checkbooks Return the checkbooks issued for a user.
-
#get_checkbooks_with_http_info(opts = {}) ⇒ Array<(GetCheckbooksResponse, Integer, Hash)>
Get checkbooks Return the checkbooks issued for a user.
-
#initialize(api_client = ApiClient.default) ⇒ Checkbook
constructor
A new instance of Checkbook.
-
#order_checkbook(base_checkbook_request, opts = {}) ⇒ GetCheckbookResponse
Order a checkbook Order a new Checkbook > [!NOTE] > The address printed on the checkbook is the user’s merchant address provided in ‘merchant` object when calling [`PUT /v3/user`](#tag/user/put/v3/user).
-
#order_checkbook_with_http_info(base_checkbook_request, opts = {}) ⇒ Array<(GetCheckbookResponse, Integer, Hash)>
Order a checkbook Order a new Checkbook > [!NOTE] > The address printed on the checkbook is the user's merchant address provided in `merchant` object when calling [`PUT /v3/user`](#tag/user/put/v3/user).
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/checkbook/api/checkbook.rb', line 17 def api_client @api_client end |
Instance Method Details
#delete_checkbook(checkbook_id, opts = {}) ⇒ nil
Cancel a checkbook Cancel the specified checkbook order
27 28 29 30 |
# File 'lib/checkbook/api/checkbook.rb', line 27 def delete_checkbook(checkbook_id, opts = {}) delete_checkbook_with_http_info(checkbook_id, opts) nil end |
#delete_checkbook_with_http_info(checkbook_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Cancel a checkbook Cancel the specified checkbook order
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/checkbook/api/checkbook.rb', line 37 def delete_checkbook_with_http_info(checkbook_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Checkbook.delete_checkbook ...' end # verify the required parameter 'checkbook_id' is set if @api_client.config.client_side_validation && checkbook_id.nil? fail ArgumentError, "Missing the required parameter 'checkbook_id' when calling Checkbook.delete_checkbook" end # resource path local_var_path = '/v3/checkbook/{checkbook_id}'.sub('{' + 'checkbook_id' + '}', CGI.escape(checkbook_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"Checkbook.delete_checkbook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Checkbook#delete_checkbook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_checkbook(checkbook_id, opts = {}) ⇒ GetCheckbookResponse
Get checkbook Get the specified checkbook
90 91 92 93 |
# File 'lib/checkbook/api/checkbook.rb', line 90 def get_checkbook(checkbook_id, opts = {}) data, _status_code, _headers = get_checkbook_with_http_info(checkbook_id, opts) data end |
#get_checkbook_tracking(checkbook_id, opts = {}) ⇒ GetCheckbookTrackingResponseExpress
Get tracking details on checkbooks Get tracking details on checkbook
153 154 155 156 |
# File 'lib/checkbook/api/checkbook.rb', line 153 def get_checkbook_tracking(checkbook_id, opts = {}) data, _status_code, _headers = get_checkbook_tracking_with_http_info(checkbook_id, opts) data end |
#get_checkbook_tracking_with_http_info(checkbook_id, opts = {}) ⇒ Array<(GetCheckbookTrackingResponseExpress, Integer, Hash)>
Get tracking details on checkbooks Get tracking details on checkbook
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/checkbook/api/checkbook.rb', line 163 def get_checkbook_tracking_with_http_info(checkbook_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Checkbook.get_checkbook_tracking ...' end # verify the required parameter 'checkbook_id' is set if @api_client.config.client_side_validation && checkbook_id.nil? fail ArgumentError, "Missing the required parameter 'checkbook_id' when calling Checkbook.get_checkbook_tracking" end # resource path local_var_path = '/v3/checkbook/{checkbook_id}/tracking'.sub('{' + 'checkbook_id' + '}', CGI.escape(checkbook_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetCheckbookTrackingResponseExpress' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"Checkbook.get_checkbook_tracking", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Checkbook#get_checkbook_tracking\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_checkbook_with_http_info(checkbook_id, opts = {}) ⇒ Array<(GetCheckbookResponse, Integer, Hash)>
Get checkbook Get the specified checkbook
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/checkbook/api/checkbook.rb', line 100 def get_checkbook_with_http_info(checkbook_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Checkbook.get_checkbook ...' end # verify the required parameter 'checkbook_id' is set if @api_client.config.client_side_validation && checkbook_id.nil? fail ArgumentError, "Missing the required parameter 'checkbook_id' when calling Checkbook.get_checkbook" end # resource path local_var_path = '/v3/checkbook/{checkbook_id}'.sub('{' + 'checkbook_id' + '}', CGI.escape(checkbook_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetCheckbookResponse' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"Checkbook.get_checkbook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Checkbook#get_checkbook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_checkbooks(opts = {}) ⇒ GetCheckbooksResponse
Get checkbooks Return the checkbooks issued for a user
218 219 220 221 |
# File 'lib/checkbook/api/checkbook.rb', line 218 def get_checkbooks(opts = {}) data, _status_code, _headers = get_checkbooks_with_http_info(opts) data end |
#get_checkbooks_with_http_info(opts = {}) ⇒ Array<(GetCheckbooksResponse, Integer, Hash)>
Get checkbooks Return the checkbooks issued for a user
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/checkbook/api/checkbook.rb', line 230 def get_checkbooks_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Checkbook.get_checkbooks ...' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling Checkbook.get_checkbooks, must be greater than or equal to 1.' end allowable_values = [10, 25, 50] if @api_client.config.client_side_validation && opts[:'per_page'] && !allowable_values.include?(opts[:'per_page']) fail ArgumentError, "invalid value for \"per_page\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'q'].nil? && opts[:'q'].to_s.length > 180 fail ArgumentError, 'invalid value for "opts[:"q"]" when calling Checkbook.get_checkbooks, the character length must be smaller than or equal to 180.' end # resource path local_var_path = '/v3/checkbook' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetCheckbooksResponse' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"Checkbook.get_checkbooks", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Checkbook#get_checkbooks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#order_checkbook(base_checkbook_request, opts = {}) ⇒ GetCheckbookResponse
Order a checkbook Order a new Checkbook > [!NOTE] > The address printed on the checkbook is the user’s merchant address provided in ‘merchant` object when calling [`PUT /v3/user`](#tag/user/put/v3/user). If the user does not have a merchant address, the shipping address provided in the `recipient` object will be printed on the checkbook.
294 295 296 297 |
# File 'lib/checkbook/api/checkbook.rb', line 294 def order_checkbook(base_checkbook_request, opts = {}) data, _status_code, _headers = order_checkbook_with_http_info(base_checkbook_request, opts) data end |
#order_checkbook_with_http_info(base_checkbook_request, opts = {}) ⇒ Array<(GetCheckbookResponse, Integer, Hash)>
Order a checkbook Order a new Checkbook > [!NOTE] > The address printed on the checkbook is the user's merchant address provided in `merchant` object when calling [`PUT /v3/user`](#tag/user/put/v3/user). If the user does not have a merchant address, the shipping address provided in the `recipient` object will be printed on the checkbook.
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/checkbook/api/checkbook.rb', line 304 def order_checkbook_with_http_info(base_checkbook_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Checkbook.order_checkbook ...' end # verify the required parameter 'base_checkbook_request' is set if @api_client.config.client_side_validation && base_checkbook_request.nil? fail ArgumentError, "Missing the required parameter 'base_checkbook_request' when calling Checkbook.order_checkbook" end # resource path local_var_path = '/v3/checkbook' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(base_checkbook_request) # return_type return_type = opts[:debug_return_type] || 'GetCheckbookResponse' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"Checkbook.order_checkbook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Checkbook#order_checkbook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |