Class: Checkbook::Invoice
- Inherits:
-
Object
- Object
- Checkbook::Invoice
- Defined in:
- lib/checkbook/api/invoice.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#delete_invoice(invoice_id, opts = {}) ⇒ nil
Void an invoice Cancel the specified invoice.
-
#delete_invoice_with_http_info(invoice_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Void an invoice Cancel the specified invoice.
-
#get_invoice(invoice_id, opts = {}) ⇒ GetInvoiceResponse
Get invoice Get the specified invoice.
-
#get_invoice_attachment(invoice_id, opts = {}) ⇒ File
Get attachment for an invoice Get the attachment for an invoice.
-
#get_invoice_attachment_with_http_info(invoice_id, opts = {}) ⇒ Array<(File, Integer, Hash)>
Get attachment for an invoice Get the attachment for an invoice.
-
#get_invoice_with_http_info(invoice_id, opts = {}) ⇒ Array<(GetInvoiceResponse, Integer, Hash)>
Get invoice Get the specified invoice.
-
#get_invoices(opts = {}) ⇒ GetInvoicesResponse
Get sent/received invoices Get sent/received invoices.
-
#get_invoices_with_http_info(opts = {}) ⇒ Array<(GetInvoicesResponse, Integer, Hash)>
Get sent/received invoices Get sent/received invoices.
-
#initialize(api_client = ApiClient.default) ⇒ Invoice
constructor
A new instance of Invoice.
-
#post_invoice(create_invoice_request, opts = {}) ⇒ CreateInvoiceResponse
Create an invoice Create a new invoice.
-
#post_invoice_payment(pay_invoice_request, opts = {}) ⇒ PayInvoiceResponse
Pay an invoice Pay an outstanding invoice.
-
#post_invoice_payment_with_http_info(pay_invoice_request, opts = {}) ⇒ Array<(PayInvoiceResponse, Integer, Hash)>
Pay an invoice Pay an outstanding invoice.
-
#post_invoice_with_http_info(create_invoice_request, opts = {}) ⇒ Array<(CreateInvoiceResponse, Integer, Hash)>
Create an invoice Create a new invoice.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/checkbook/api/invoice.rb', line 17 def api_client @api_client end |
Instance Method Details
#delete_invoice(invoice_id, opts = {}) ⇒ nil
Void an invoice Cancel the specified invoice
27 28 29 30 |
# File 'lib/checkbook/api/invoice.rb', line 27 def delete_invoice(invoice_id, opts = {}) delete_invoice_with_http_info(invoice_id, opts) nil end |
#delete_invoice_with_http_info(invoice_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Void an invoice Cancel the specified invoice
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/checkbook/api/invoice.rb', line 37 def delete_invoice_with_http_info(invoice_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Invoice.delete_invoice ...' end # verify the required parameter 'invoice_id' is set if @api_client.config.client_side_validation && invoice_id.nil? fail ArgumentError, "Missing the required parameter 'invoice_id' when calling Invoice.delete_invoice" end # resource path local_var_path = '/v3/invoice/{invoice_id}'.sub('{' + 'invoice_id' + '}', CGI.escape(invoice_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"Invoice.delete_invoice", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Invoice#delete_invoice\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_invoice(invoice_id, opts = {}) ⇒ GetInvoiceResponse
Get invoice Get the specified invoice
90 91 92 93 |
# File 'lib/checkbook/api/invoice.rb', line 90 def get_invoice(invoice_id, opts = {}) data, _status_code, _headers = get_invoice_with_http_info(invoice_id, opts) data end |
#get_invoice_attachment(invoice_id, opts = {}) ⇒ File
Get attachment for an invoice Get the attachment for an invoice
153 154 155 156 |
# File 'lib/checkbook/api/invoice.rb', line 153 def (invoice_id, opts = {}) data, _status_code, _headers = (invoice_id, opts) data end |
#get_invoice_attachment_with_http_info(invoice_id, opts = {}) ⇒ Array<(File, Integer, Hash)>
Get attachment for an invoice Get the attachment for an invoice
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/checkbook/api/invoice.rb', line 163 def (invoice_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Invoice.get_invoice_attachment ...' end # verify the required parameter 'invoice_id' is set if @api_client.config.client_side_validation && invoice_id.nil? fail ArgumentError, "Missing the required parameter 'invoice_id' when calling Invoice.get_invoice_attachment" end # resource path local_var_path = '/v3/invoice/{invoice_id}/attachment'.sub('{' + 'invoice_id' + '}', CGI.escape(invoice_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/pdf', 'application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'File' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"Invoice.get_invoice_attachment", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Invoice#get_invoice_attachment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_invoice_with_http_info(invoice_id, opts = {}) ⇒ Array<(GetInvoiceResponse, Integer, Hash)>
Get invoice Get the specified invoice
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/checkbook/api/invoice.rb', line 100 def get_invoice_with_http_info(invoice_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Invoice.get_invoice ...' end # verify the required parameter 'invoice_id' is set if @api_client.config.client_side_validation && invoice_id.nil? fail ArgumentError, "Missing the required parameter 'invoice_id' when calling Invoice.get_invoice" end # resource path local_var_path = '/v3/invoice/{invoice_id}'.sub('{' + 'invoice_id' + '}', CGI.escape(invoice_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetInvoiceResponse' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"Invoice.get_invoice", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Invoice#get_invoice\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_invoices(opts = {}) ⇒ GetInvoicesResponse
Get sent/received invoices Get sent/received invoices
223 224 225 226 |
# File 'lib/checkbook/api/invoice.rb', line 223 def get_invoices(opts = {}) data, _status_code, _headers = get_invoices_with_http_info(opts) data end |
#get_invoices_with_http_info(opts = {}) ⇒ Array<(GetInvoicesResponse, Integer, Hash)>
Get sent/received invoices Get sent/received invoices
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/checkbook/api/invoice.rb', line 240 def get_invoices_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Invoice.get_invoices ...' end allowable_values = ["INCOMING", "OUTGOING"] if @api_client.config.client_side_validation && opts[:'direction'] && !allowable_values.include?(opts[:'direction']) fail ArgumentError, "invalid value for \"direction\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling Invoice.get_invoices, must be greater than or equal to 1.' end allowable_values = [10, 25, 50, 100, 250] if @api_client.config.client_side_validation && opts[:'per_page'] && !allowable_values.include?(opts[:'per_page']) fail ArgumentError, "invalid value for \"per_page\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'q'].nil? && opts[:'q'].to_s.length > 180 fail ArgumentError, 'invalid value for "opts[:"q"]" when calling Invoice.get_invoices, the character length must be smaller than or equal to 180.' end allowable_values = ["+NUMBER", "-NUMBER", "+TYPE", "-TYPE", "+AMOUNT", "-AMOUNT", "+STATUS", "-STATUS", "+DATE", "-DATE", "+UPDATE", "-UPDATE", "+DESCRIPTION", "-DESCRIPTION"] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end allowable_values = ["PAID", "IN_PROCESS", "UNPAID", "VOID", "EXPIRED", "PRINTED", "MAILED", "FAILED", "REFUNDED"] if @api_client.config.client_side_validation && opts[:'status'] && !allowable_values.include?(opts[:'status']) fail ArgumentError, "invalid value for \"status\", must be one of #{allowable_values}" end # resource path local_var_path = '/v3/invoice' # query parameters query_params = opts[:query_params] || {} query_params[:'direction'] = opts[:'direction'] if !opts[:'direction'].nil? query_params[:'end_date'] = opts[:'end_date'] if !opts[:'end_date'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'start_date'] = opts[:'start_date'] if !opts[:'start_date'].nil? query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetInvoicesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"Invoice.get_invoices", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Invoice#get_invoices\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_invoice(create_invoice_request, opts = {}) ⇒ CreateInvoiceResponse
Create an invoice Create a new invoice
321 322 323 324 |
# File 'lib/checkbook/api/invoice.rb', line 321 def post_invoice(create_invoice_request, opts = {}) data, _status_code, _headers = post_invoice_with_http_info(create_invoice_request, opts) data end |
#post_invoice_payment(pay_invoice_request, opts = {}) ⇒ PayInvoiceResponse
Pay an invoice Pay an outstanding invoice
389 390 391 392 |
# File 'lib/checkbook/api/invoice.rb', line 389 def post_invoice_payment(pay_invoice_request, opts = {}) data, _status_code, _headers = post_invoice_payment_with_http_info(pay_invoice_request, opts) data end |
#post_invoice_payment_with_http_info(pay_invoice_request, opts = {}) ⇒ Array<(PayInvoiceResponse, Integer, Hash)>
Pay an invoice Pay an outstanding invoice
399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 |
# File 'lib/checkbook/api/invoice.rb', line 399 def post_invoice_payment_with_http_info(pay_invoice_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Invoice.post_invoice_payment ...' end # verify the required parameter 'pay_invoice_request' is set if @api_client.config.client_side_validation && pay_invoice_request.nil? fail ArgumentError, "Missing the required parameter 'pay_invoice_request' when calling Invoice.post_invoice_payment" end # resource path local_var_path = '/v3/invoice/payment' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(pay_invoice_request) # return_type return_type = opts[:debug_return_type] || 'PayInvoiceResponse' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"Invoice.post_invoice_payment", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Invoice#post_invoice_payment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_invoice_with_http_info(create_invoice_request, opts = {}) ⇒ Array<(CreateInvoiceResponse, Integer, Hash)>
Create an invoice Create a new invoice
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/checkbook/api/invoice.rb', line 331 def post_invoice_with_http_info(create_invoice_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Invoice.post_invoice ...' end # verify the required parameter 'create_invoice_request' is set if @api_client.config.client_side_validation && create_invoice_request.nil? fail ArgumentError, "Missing the required parameter 'create_invoice_request' when calling Invoice.post_invoice" end # resource path local_var_path = '/v3/invoice' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_invoice_request) # return_type return_type = opts[:debug_return_type] || 'CreateInvoiceResponse' # auth_names auth_names = opts[:debug_auth_names] || ['token'] = opts.merge( :operation => :"Invoice.post_invoice", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Invoice#post_invoice\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |